--Author: Venkata Potluri
--Date: April 04, 2015

DECLARE
   TYPE T_MEM_ID IS TABLE OF SIEBEL_PURGE.PURGE_MEM_TXN.MEMBER_ID%TYPE;

   TYPE T_RDM_SUM IS TABLE OF SIEBEL_PURGE.PURGE_MEM_TXN.RDM_SUM%TYPE;

   ARR_MEM_ID    T_MEM_ID;
   ARR_RDM_SUM   T_RDM_SUM;
   LOG_ROW_ID   NUMBER := 0;
   ROW_COUNT    NUMBER := 0;

   CURSOR C1
   IS
        SELECT /*+ parallel(A,5) FULL(A) */ A.MEMBER_ID, SUM (A.VALUE)
          FROM SIEBEL.S_LOY_RDM_ITM A
         WHERE     A.ATTRB_DEFN_ID = (SELECT NET_ATTRIB_DEFN_ID
                                      FROM SIEBEL_PURGE.PURGE_CONFIG
                                     WHERE ROW_ID = 1)
               AND A.X_PURGE_FLG IS NOT NULL
      GROUP BY A.MEMBER_ID;
BEGIN
   SELECT CASE WHEN MAX (ROW_ID) IS NOT NULL THEN MAX (ROW_ID) + 1 ELSE 1 END
     INTO LOG_ROW_ID
     FROM SIEBEL_PURGE.PURGE_LOG;

   INSERT INTO SIEBEL_PURGE.PURGE_LOG (ROW_ID, PROCESS_NAME, START_TIME)
      SELECT LOG_ROW_ID, 'Populate PURGE_MEM_TXN Part-4/6', SYSDATE
        FROM DUAL;

   COMMIT;

   OPEN C1;

   LOOP
      --FETCH C1 BULK COLLECT INTO ARR_MEM_ID, ARR_RDM_SUM LIMIT 10000;
	  FETCH C1 BULK COLLECT INTO ARR_MEM_ID, ARR_RDM_SUM LIMIT 50;

      FORALL ROW IN ARR_MEM_ID.FIRST .. ARR_MEM_ID.LAST
         UPDATE SIEBEL_PURGE.PURGE_MEM_TXN
            SET RDM_SUM = ARR_RDM_SUM (ROW)
          WHERE MEMBER_ID = ARR_MEM_ID (ROW);

      ROW_COUNT := ROW_COUNT + SQL%ROWCOUNT;

      UPDATE SIEBEL_PURGE.PURGE_LOG
         SET PROCESSED_ROWS = ROW_COUNT
       WHERE ROW_ID = LOG_ROW_ID;

      COMMIT;

      EXIT WHEN C1%NOTFOUND;
   END LOOP;

   CLOSE C1;

   UPDATE SIEBEL_PURGE.PURGE_LOG
      SET END_TIME = SYSDATE, PROCESSED_ROWS = ROW_COUNT
    WHERE ROW_ID = LOG_ROW_ID;

   COMMIT;
END;
/

QUIT