--Author: Venkata Potluri
--Date: April 08, 2015

DECLARE
   TYPE T_MEM_ID IS TABLE OF SIEBEL_PURGE.PURGE_MEM_REDEEMABLE.MEMBER_ID%TYPE;

   TYPE T_ACRL_SUM IS TABLE OF SIEBEL_PURGE.PURGE_MEM_REDEEMABLE.POST_ACRL_SUM%TYPE;

   TYPE T_USED_SUM IS TABLE OF SIEBEL_PURGE.PURGE_MEM_REDEEMABLE.POST_USED_SUM%TYPE;

   ARR_MEM_ID     T_MEM_ID;
   ARR_ACRL_SUM   T_ACRL_SUM;
   ARR_USED_SUM   T_USED_SUM;
   LOG_ROW_ID   NUMBER := 0;
   ROW_COUNT    NUMBER := 0;

   CURSOR C1
   IS
        SELECT /*+ parallel(a,12) full(a) */ MEMBER_ID, SUM (ACCRUALED_VALUE), SUM (USED_VALUE)
          FROM SIEBEL.S_LOY_ACRL_ITM a
         WHERE     ATTRIB_DEFN_ID = (SELECT NET_ATTRIB_DEFN_ID
                                       FROM SIEBEL_PURGE.PURGE_CONFIG
                                      WHERE ROW_ID = 1)
               AND MEMBER_ID IN (SELECT MEMBER_ID
                                   FROM SIEBEL_PURGE.PURGE_MEM_REDEEMABLE)
      GROUP BY MEMBER_ID;
BEGIN
   SELECT CASE WHEN MAX (ROW_ID) IS NOT NULL THEN MAX (ROW_ID) + 1 ELSE 1 END
     INTO LOG_ROW_ID
     FROM SIEBEL_PURGE.PURGE_LOG;

   INSERT INTO SIEBEL_PURGE.PURGE_LOG (ROW_ID, PROCESS_NAME, START_TIME)
      SELECT LOG_ROW_ID, 'Populate PURGE_MEM_REDEEMABLE Part-1/3 After Purge', SYSDATE
        FROM DUAL;

   COMMIT;

   OPEN C1;

   LOOP
      FETCH C1
         BULK COLLECT INTO ARR_MEM_ID, ARR_ACRL_SUM, ARR_USED_SUM
         LIMIT 10000;
		 --LIMIT 50;

      FORALL ROW IN ARR_MEM_ID.FIRST .. ARR_MEM_ID.LAST
         UPDATE SIEBEL_PURGE.PURGE_MEM_REDEEMABLE
            SET POST_ACRL_SUM = ARR_ACRL_SUM (ROW),
                POST_USED_SUM = ARR_USED_SUM (ROW)
          WHERE MEMBER_ID = ARR_MEM_ID (ROW);

      ROW_COUNT := ROW_COUNT + SQL%ROWCOUNT;

      UPDATE SIEBEL_PURGE.PURGE_LOG
         SET PROCESSED_ROWS = ROW_COUNT
       WHERE ROW_ID = LOG_ROW_ID;

      COMMIT;

      EXIT WHEN C1%NOTFOUND;
   END LOOP;

   CLOSE C1;

   UPDATE SIEBEL_PURGE.PURGE_LOG
      SET END_TIME = SYSDATE, PROCESSED_ROWS = ROW_COUNT
    WHERE ROW_ID = LOG_ROW_ID;

   COMMIT;
END;
/

QUIT